@@ -34,7 +34,9 @@ def patch_views():
     def sentry_patched_render(self):
         # type: (SimpleTemplateResponse) -> Any
         with sentry_sdk.start_span(
-            op=OP.VIEW_RESPONSE_RENDER, description="serialize response"
+            op=OP.VIEW_RESPONSE_RENDER,
+            description="serialize response",
+            origin=DjangoIntegration.origin,
         ):
             return old_render(self)
 
@@ -69,6 +71,8 @@ def patch_views():
 
 def _wrap_sync_view(callback):
     # type: (Any) -> Any
+    from sentry_sdk.integrations.django import DjangoIntegration
+
     @functools.wraps(callback)
     def sentry_wrapped_callback(request, *args, **kwargs):
         # type: (Any, *Any, **Any) -> Any
@@ -79,7 +83,9 @@ def _wrap_sync_view(callback):
             sentry_scope.profile.update_active_thread_id()
 
         with sentry_sdk.start_span(
-            op=OP.VIEW_RENDER, description=request.resolver_match.view_name
+            op=OP.VIEW_RENDER,
+            description=request.resolver_match.view_name,
+            origin=DjangoIntegration.origin,
         ):
             return callback(request, *args, **kwargs)
 
